@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.017-7-gb9ae6df
+package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.018-2-g6cc62e9
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Generate a test that shows what modules you are breaking
 # KEYWORDS: distribution prerequisites upstream dependencies modules conflicts breaks breakages metadata
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use Moose;
 with (
@@ -272,7 +272,7 @@ Dist::Zilla::Plugin::Test::CheckBreaks - Generate a test that shows what modules
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -422,7 +422,7 @@ SKIP: {
         my $module = $_;
         my $filename = $modules->{$module};
         <<"CHECK_CONFLICTS";
-    eval 'require $module; ${module}->check_conflicts';
+    eval { +require $module; ${module}->check_conflicts };
     skip('no $module module found', 1) if not \$INC{'$filename'};
 
     diag \$@ if \$@;
@@ -449,9 +449,9 @@ CHECK_BREAKS_header
 
         $breaks_content .= $no_forced_deps ? <<CHECK_BREAKS_prereq_nodeps
 skip 'This information-only test requires CPAN::Meta::Requirements', 1
-    if not eval 'require CPAN::Meta::Requirements';
+    if not eval { +require CPAN::Meta::Requirements };
 skip 'This information-only test requires CPAN::Meta::Check $cmc_prereq', 1
-    if not eval 'require CPAN::Meta::Check; CPAN::Meta::Check->VERSION($cmc_prereq)';
+    if not eval { +require CPAN::Meta::Check; CPAN::Meta::Check->VERSION($cmc_prereq) };
 CHECK_BREAKS_prereq_nodeps
             : <<CHECK_BREAKS_prereq_deps;
 use CPAN::Meta::Requirements;
